@@ -260,6 +260,23 @@ class TestSections(unittest.TestCase):
                     (HoleType.OPEN_HOLE, 8.5, 8.25, 20528.9, 20539.77),
                     (HoleType.OPEN_HOLE, 8.5, 6.75, 20539.77, 20633.0),
                 )
+            },
+            "depth_activation": {
+                "hole": (
+                    (HoleType.CASED_HOLE, 8.835, 0.0, 9890.0),
+                    (HoleType.OPEN_HOLE, 8.75, 9890.0, 9891.0),
+                    (HoleType.OPEN_HOLE, 8.5, 9891.0, 15205.17),
+                    (HoleType.OPEN_HOLE, 12.0, 15205.17, 20539.77),
+                    (HoleType.OPEN_HOLE, 8.5, 20539.77, 20633.0)
+                ),
+                "annulus": (
+                    (HoleType.CASED_HOLE, 8.835, 5.0, 0, 9890.0),
+                    (HoleType.OPEN_HOLE, 8.75, 5.0, 9890.0, 9891.0),
+                    (HoleType.OPEN_HOLE, 8.5, 5.0, 9891.0, 15205.17),
+                    (HoleType.OPEN_HOLE, 12.0, 5.0, 15205.17, 20528.9),
+                    (HoleType.OPEN_HOLE, 12.0, 8.25, 20528.9, 20539.77),
+                    (HoleType.OPEN_HOLE, 8.5, 6.75, 20539.77, 20633.0),
+                )
             }
         }
 
@@ -296,6 +313,8 @@ class TestSections(unittest.TestCase):
 
             if activation_type == "unactivated":
                 self.assertEqual(10_000_000.0, under_reamer_component.get("ur_opened_depth"))
+            elif activation_type == "depth_activation":
+                self.assertEqual(15205.17, under_reamer_component.get("ur_opened_depth"))
             else:
                 self.assertIsNone(under_reamer_component.get("ur_opened_depth"))
 
@@ -749,12 +768,14 @@ def get_wits():
     return file_to_json(wits_json_file)
 
 
-def reset_drillstring(activation_type="flow_activated"):
-    activation_depth = None
+def reset_drillstring(activation_type="flow_activated", activation_depth=None):
     if activation_type == "unactivated":
         activation_type = "flow_activated"
         activation_depth = 10_000_000.0
 
+    elif activation_type == "depth_activation":
+        activation_depth = 15205.17
+
     api_worker = API()
     path = "/v1/data/corva/data.drillstring/5ebaceeac93924003a922593"
     drillstring = api_worker.get(path=path).data
