@@ -3,7 +3,7 @@ from itertools import groupby
 from worker.app.modules.__init__ import Module
 from worker.data.api import API
 from worker.data import operations
-from worker.data.operations import get_drillstring_by_id
+from worker.data.operations import get_config_by_id
 from worker.framework import constants
 
 
@@ -141,7 +141,7 @@ class ActivityModule(Module):
 
         drillstring_number = None
         if active_string_type == 'drillstring':
-            drillstring = get_drillstring_by_id(active_string_id)
+            drillstring = get_config_by_id(active_string_id, collection="data.drillstring")
 
             if drillstring:
                 drillstring_number = drillstring.get('data', {}).get('id', None)
