@@ -25,7 +25,7 @@ class Scheduler(Module):
             if self.should_run_processor(el):
                 results = self.run_module(el, results)
 
-        self.save_module_state()
+        self.save_state()
         self.store_output(self.global_state['asset_id'], results)
 
     # override
