@@ -1,7 +1,6 @@
 from typing import Union, List
 
 from worker.event import Event, EventType
-from worker.framework.constants import api
 
 
 class SingleScheduledEvent:
@@ -12,7 +11,7 @@ class SingleScheduledEvent:
         self.end_time = single_stream_event.get('schedule_end', 0) / 1000
         self.schedule_id = single_stream_event.get('schedule')
 
-    def complete_event(self) -> None:
+    def complete_event(self, api) -> None:
         """Sets schedule as completed."""
         if not self.schedule_id:
             return
@@ -37,6 +36,6 @@ class ScheduledEvent(Event):
 
         super().add_records(new_records)
 
-    def complete_event(self) -> None:
+    def complete_event(self, api) -> None:
         for each in self.records:
-            each.complete_event()
+            each.complete_event(api)
